import React, { useState, useEffect } from 'react';
import { Button } from '../buttons'; // Adjust the import path according to your project structure
import { DarkMode, LightMode } from '@mui/icons-material';

const ColorMode = () => {
  // Initialize theme state without setting a default yet
  const [theme, setTheme] = useState<string>('');

  // Function to update the body class and local storage
  const applyTheme = (themeValue: string) => {
    document.body.className = themeValue;
    localStorage.setItem('theme', themeValue);
  };

  // Load the theme preference from local storage on initial render
  useEffect(() => {
    const savedTheme = localStorage.getItem('theme');
    if (savedTheme) {
      setTheme(savedTheme);
    } else {
      // Fallback to system preference if no saved theme
      // const prefersDarkMode = window.matchMedia('(prefers-color-scheme: dark)').matches;
      const prefersDarkMode = false; // TODO: remove once dark theme is fixed
      const defaultTheme = prefersDarkMode ? 'dark-mode' : 'light-mode';
      setTheme(defaultTheme);
      applyTheme(defaultTheme);
    }
  }, []);

  // Update the local storage and body class whenever the theme changes
  useEffect(() => {
    if (theme) {
      applyTheme(theme);
    }
  }, [theme]);

  // Function to toggle the theme
  const toggleTheme = () => {
    setTheme((currentTheme) => (currentTheme === 'light-mode' ? 'dark-mode' : 'light-mode'));
  };
  const iconComponent = theme === 'dark-mode' ? <DarkMode /> : <LightMode />;

  return <Button variant="ghost" iconComponent={iconComponent} onClick={toggleTheme} />;
};

export default ColorMode;
