import React, { ReactNode } from 'react';

export interface BarTooltipProps {
  x: number;
  y: number;
  content: React.ReactNode;
}

export const BarplotTooltip: React.FC<BarTooltipProps> = ({ x, y, content }) => {
  return (
    <div className="absolute font-sans bg-light border border-secondary text-secondary p-2" style={{ left: `${x}px`, top: `${y}px` }}>
      {content}
    </div>
  );
};

export type TooltipProps = {
  position?: 'top' | 'bottom' | 'left' | 'right';
  children: ReactNode;
  tooltip: string;
};

export default function Tooltip({ position = 'bottom', children, tooltip }: TooltipProps) {
  return (
    <div className="group relative cursor-pointer">
      <div className="mx-2 my-2">{children}</div>
      <span
        className={`absolute hidden group-hover:inline-block bg-neutral-900 text-white text-xs p-2 whitespace-nowrap rounded ${
          position === 'top' ? 'left-1/2 -translate-x-1/2 bottom-[calc(100%+5px)]' : ''
        } ${position === 'bottom' ? 'left-1/2 -translate-x-1/2 top-[calc(100%+5px)]' : ''} ${
          position === 'left' ? 'top-1/2 -translate-y-1/2 right-[calc(100%+5px)]' : ''
        } ${position === 'right' ? 'top-1/2 -translate-y-1/2 left-[calc(100%+5px)]' : ''} `}
      >
        {tooltip}
      </span>
      <span
        className={`absolute hidden group-hover:inline-block border-[6px] ${
          position === 'top'
            ? 'left-1/2 -translate-x-1/2 bottom-full border-l-transparent border-r-transparent border-b-0 border-t-neutral-900'
            : ''
        } ${
          position === 'bottom'
            ? 'left-1/2 -translate-x-1/2 top-full border-l-transparent border-r-transparent border-t-0 border-b-neutral-900'
            : ''
        } ${
          position === 'left'
            ? 'top-1/2 -translate-y-1/2 right-full border-t-transparent border-b-transparent border-r-0 border-l-neutral-900'
            : ''
        } ${
          position === 'right'
            ? 'top-1/2 -translate-y-1/2 left-full border-t-transparent border-b-transparent border-l-0 border-r-neutral-900'
            : ''
        } `}
      ></span>
    </div>
  );
}
